Affinity
  Restricts instances belonging to the server group to the same host.
Anti Affinity
  Restricts instances belonging to the server group to separate hosts.
Soft Affinity
  Attempts to restrict instances belonging to the server group to the same host. Where it is not possible to schedule all instances on one host, they will be scheduled together on as few hosts as possible.
Soft Anti Affinity
  Attempts to restrict instances belonging to the server group to separate hosts. Where it is not possible to schedule all instances to separate hosts, they will be scheduled on as many separate hosts as possible.